-- Adds currency support by introducing two new tables: currency (keeps all the currencies defined in the application) and exchangerate (used by invoices to convert their items and expenses to the invoice currency).  

CREATE TABLE currency (
	businessid BIGINT NOT NULL,
	code VARCHAR(255),
	CONSTRAINT fk_currency_businessid FOREIGN KEY (businessid) REFERENCES PUBLIC.business(businessid)
);

CREATE TABLE exchangerate (
	invoiceid BIGINT NOT NULL,
	source VARCHAR(255),
	target VARCHAR(255),
	rate NUMERIC,
	CONSTRAINT fk_exchangerate_invoiceid FOREIGN KEY (invoiceid) REFERENCES PUBLIC.invoice(invoiceid)
);

-- All entities (business, item, expense, service, invoice) that deal with money have an additional field for the currency
-- that is initialized to the default currency (specified using the ${currency} placeholder)

ALTER TABLE business ADD defaultcurrency VARCHAR(255);
ALTER TABLE expense ADD currency VARCHAR(255);
ALTER TABLE item ADD currency VARCHAR(255);
ALTER TABLE service ADD currency VARCHAR(255);
ALTER TABLE invoice ADD currency VARCHAR(255);

UPDATE business SET defaultcurrency='${currency}';
UPDATE expense SET currency='${currency}';
UPDATE item SET currency='${currency}';
UPDATE service SET currency='${currency}';
UPDATE invoice SET currency='${currency}';

-- Add the default currency to the currency table

INSERT INTO currency(businessid) SELECT businessid FROM business;
UPDATE currency SET code='${currency}';
